@@ -194,13 +194,21 @@ struct _ClutterTransformInfo
   /* scaling */
   gdouble scale_x;
   gdouble scale_y;
+  gdouble scale_z;
   AnchorCoord scale_center;
 
   /* anchor point */
   AnchorCoord anchor;
 
-  /* depth */
-  gfloat depth;
+  /* translation */
+  ClutterVertex translation;
+
+  /* z_position */
+  gfloat z_position;
+
+  /* transformation center */
+  ClutterPoint pivot;
+  gfloat pivot_z;
 };
 
 const ClutterTransformInfo *    _clutter_actor_get_transform_info_or_defaults   (ClutterActor *self);
@@ -298,6 +306,9 @@ void    _clutter_actor_shader_post_paint        (ClutterActor *actor);
 
 ClutterActorAlign       _clutter_actor_get_effective_x_align    (ClutterActor *self);
 
+void            _clutter_actor_handle_event             (ClutterActor       *actor,
+                                                         const ClutterEvent *event);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ACTOR_PRIVATE_H__ */
