@@ -399,9 +399,11 @@ void                            clutter_actor_set_x
                                                                                  gfloat                       x);
 void                            clutter_actor_set_y                             (ClutterActor                *self,
                                                                                  gfloat                       y);
-void                            clutter_actor_set_depth                         (ClutterActor                *self,
-                                                                                 gfloat                       depth);
-gfloat                          clutter_actor_get_depth                         (ClutterActor                *self);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_z_position                    (ClutterActor                *self,
+                                                                                 gfloat                       z_position);
+CLUTTER_AVAILABLE_IN_1_12
+gfloat                          clutter_actor_get_z_position                    (ClutterActor                *self);
 CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_set_layout_manager                (ClutterActor                *self,
                                                                                  ClutterLayoutManager        *manager);
@@ -533,7 +535,7 @@ gboolean                        clutter_actor_get_reactive
 gboolean                        clutter_actor_has_key_focus                     (ClutterActor               *self);
 void                            clutter_actor_grab_key_focus                    (ClutterActor               *self);
 gboolean                        clutter_actor_event                             (ClutterActor               *actor,
-                                                                                 ClutterEvent               *event,
+                                                                                 const ClutterEvent         *event,
                                                                                  gboolean                    capture);
 gboolean                        clutter_actor_has_pointer                       (ClutterActor               *self);
 
@@ -617,58 +619,53 @@ CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_iter_remove                       (ClutterActorIter           *iter);
 CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_iter_destroy                      (ClutterActorIter           *iter);
+CLUTTER_AVAILABLE_IN_1_12
+gboolean                        clutter_actor_iter_is_valid                     (const ClutterActorIter     *iter);
 
 /* Transformations */
 gboolean                        clutter_actor_is_rotated                        (ClutterActor               *self);
 gboolean                        clutter_actor_is_scaled                         (ClutterActor               *self);
-void                            clutter_actor_set_rotation                      (ClutterActor               *self,
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_pivot_point                   (ClutterActor               *self,
+                                                                                 gfloat                      pivot_x,
+                                                                                 gfloat                      pivot_y);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_get_pivot_point                   (ClutterActor               *self,
+                                                                                 gfloat                     *pivot_x,
+                                                                                 gfloat                     *pivot_y);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_pivot_point_z                 (ClutterActor               *self,
+                                                                                 gfloat                      pivot_z);
+CLUTTER_AVAILABLE_IN_1_12
+gfloat                          clutter_actor_get_pivot_point_z                 (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_rotation_angle                (ClutterActor               *self,
                                                                                  ClutterRotateAxis           axis,
-                                                                                 gdouble                     angle,
-                                                                                 gfloat                      x,
-                                                                                 gfloat                      y,
-                                                                                 gfloat                      z);
-void                            clutter_actor_set_z_rotation_from_gravity       (ClutterActor               *self,
-                                                                                 gdouble                     angle,
-                                                                                 ClutterGravity              gravity);
-gdouble                         clutter_actor_get_rotation                      (ClutterActor               *self,
-                                                                                 ClutterRotateAxis           axis,
-                                                                                 gfloat                     *x,
-                                                                                 gfloat                     *y,
-                                                                                 gfloat                     *z);
-ClutterGravity                  clutter_actor_get_z_rotation_gravity            (ClutterActor               *self);
+                                                                                 gdouble                     angle);
+CLUTTER_AVAILABLE_IN_1_12
+gdouble                         clutter_actor_get_rotation_angle                (ClutterActor               *self,
+                                                                                 ClutterRotateAxis           axis);
 void                            clutter_actor_set_scale                         (ClutterActor               *self,
                                                                                  gdouble                     scale_x,
                                                                                  gdouble                     scale_y);
-void                            clutter_actor_set_scale_full                    (ClutterActor               *self,
-                                                                                 gdouble                     scale_x,
-                                                                                 gdouble                     scale_y,
-                                                                                 gfloat                      center_x,
-                                                                                 gfloat                      center_y);
-void                            clutter_actor_set_scale_with_gravity            (ClutterActor               *self,
-                                                                                 gdouble                     scale_x,
-                                                                                 gdouble                     scale_y,
-                                                                                 ClutterGravity              gravity);
 void                            clutter_actor_get_scale                         (ClutterActor               *self,
                                                                                  gdouble                    *scale_x,
                                                                                  gdouble                    *scale_y);
-void                            clutter_actor_get_scale_center                  (ClutterActor               *self,
-                                                                                 gfloat                     *center_x,
-                                                                                 gfloat                     *center_y);
-ClutterGravity                  clutter_actor_get_scale_gravity                 (ClutterActor               *self);
-void                            clutter_actor_set_anchor_point                  (ClutterActor               *self,
-                                                                                 gfloat                      anchor_x,
-                                                                                 gfloat                      anchor_y);
-void                            clutter_actor_move_anchor_point                 (ClutterActor               *self,
-                                                                                 gfloat                      anchor_x,
-                                                                                 gfloat                      anchor_y);
-void                            clutter_actor_get_anchor_point                  (ClutterActor               *self,
-                                                                                 gfloat                     *anchor_x,
-                                                                                 gfloat                     *anchor_y);
-ClutterGravity                  clutter_actor_get_anchor_point_gravity          (ClutterActor               *self);
-void                            clutter_actor_set_anchor_point_from_gravity     (ClutterActor               *self,
-                                                                                 ClutterGravity              gravity);
-void                            clutter_actor_move_anchor_point_from_gravity    (ClutterActor               *self,
-                                                                                 ClutterGravity              gravity);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_scale_z                       (ClutterActor               *self,
+                                                                                 gdouble                     scale_z);
+CLUTTER_AVAILABLE_IN_1_12
+gdouble                         clutter_actor_get_scale_z                       (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_translation                   (ClutterActor               *self,
+                                                                                 gfloat                      translate_x,
+                                                                                 gfloat                      translate_y,
+                                                                                 gfloat                      translate_z);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_get_translation                   (ClutterActor               *self,
+                                                                                 gfloat                     *translate_x,
+                                                                                 gfloat                     *translate_y,
+                                                                                 gfloat                     *translate_z);
 void                            clutter_actor_get_transformed_position          (ClutterActor               *self,
                                                                                  gfloat                     *x,
                                                                                  gfloat                     *y);
