@@ -377,6 +377,26 @@ G_DEFINE_BOXED_TYPE (ClutterMargin, clutter_margin,
  * ClutterPoint
  */
 
+static const ClutterPoint _clutter_point_zero = CLUTTER_POINT_INIT_ZERO;
+
+/**
+ * clutter_point_zero:
+ *
+ * A point centered at (0, 0).
+ *
+ * The returned value can be used as a guard.
+ *
+ * Return value: a point centered in (0, 0); the returned #ClutterPoint
+ *   is owned by Clutter and it should not be modified or freed.
+ *
+ * Since: 1.12
+ */
+const ClutterPoint *
+clutter_point_zero (void)
+{
+  return &_clutter_point_zero;
+}
+
 /**
  * clutter_point_alloc:
  *
@@ -446,7 +466,7 @@ clutter_point_copy (const ClutterPoint *point)
 void
 clutter_point_free (ClutterPoint *point)
 {
-  if (point != NULL)
+  if (point != NULL && point != &_clutter_point_zero)
     g_slice_free (ClutterPoint, point);
 }
 
@@ -672,6 +692,8 @@ G_DEFINE_BOXED_TYPE_WITH_CODE (ClutterSize, clutter_size,
  * ClutterRect
  */
 
+static const ClutterRect _clutter_rect_zero = CLUTTER_RECT_INIT_ZERO;
+
 static gboolean clutter_rect_progress (const GValue *a,
                                        const GValue *b,
                                        gdouble       progress,
@@ -705,6 +727,26 @@ clutter_rect_normalize_internal (ClutterRect *rect)
     }
 }
 
+/**
+ * clutter_rect_zero:
+ *
+ * A #ClutterRect with #ClutterRect.origin set at (0, 0) and a size
+ * of 0.
+ *
+ * The returned value can be used as a guard.
+ *
+ * Return value: a rectangle with origin in (0, 0) and a size of 0.
+ *   The returned #ClutterRect is owned by Clutter and it should not
+ *   be modified or freed.
+ *
+ * Since: 1.12
+ */
+const ClutterRect *
+clutter_rect_zero (void)
+{
+  return &_clutter_rect_zero;
+}
+
 /**
  * clutter_rect_alloc:
  *
@@ -798,7 +840,7 @@ clutter_rect_copy (const ClutterRect *rect)
 void
 clutter_rect_free (ClutterRect *rect)
 {
-  if (rect != NULL)
+  if (rect != NULL && rect != &_clutter_rect_zero)
     g_slice_free (ClutterRect, rect);
 }
 
