@@ -50,6 +50,16 @@ typedef struct _ClutterKeyInfo
   ClutterModifierType modifiers;
 } ClutterKeyInfo;
 
+typedef struct _ClutterScrollInfo
+{
+  guint axis_id;
+  ClutterScrollDirection direction;
+  gdouble increment;
+
+  gdouble last_value;
+  guint last_value_valid : 1;
+} ClutterScrollInfo;
+
 struct _ClutterInputDevice
 {
   GObject parent_instance;
@@ -76,6 +86,8 @@ struct _ClutterInputDevice
   /* the actor that has a grab in place for the device */
   ClutterActor *pointer_grab_actor;
   ClutterActor *keyboard_grab_actor;
+  GHashTable   *sequence_grab_actors;
+  GHashTable   *inv_sequence_grab_actors;
 
   /* the current click count */
   gint click_count;
@@ -102,6 +114,8 @@ struct _ClutterInputDevice
   guint n_keys;
   GArray *keys;
 
+  GArray *scroll_info;
+
   guint has_cursor : 1;
   guint is_enabled : 1;
 };
@@ -170,6 +184,17 @@ gboolean        _clutter_input_device_translate_axis            (ClutterInputDev
                                                                  gdouble               value,
                                                                  gdouble              *axis_value);
 
+void            _clutter_input_device_add_scroll_info           (ClutterInputDevice   *device,
+                                                                 guint                 index_,
+                                                                 ClutterScrollDirection direction,
+                                                                 gdouble               increment);
+void            _clutter_input_device_reset_scroll_info         (ClutterInputDevice   *device);
+gboolean        _clutter_input_device_get_scroll_delta          (ClutterInputDevice   *device,
+                                                                 guint                 index_,
+                                                                 gdouble               value,
+                                                                 ClutterScrollDirection *direction_p,
+                                                                 gdouble                *delta_p);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_DEVICE_MANAGER_PRIVATE_H__ */
