@@ -75,6 +75,8 @@ typedef struct _ClutterMainContext      ClutterMainContext;
 #define CLUTTER_PARAM_WRITABLE  (G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS)
 #define CLUTTER_PARAM_READWRITE (G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS)
 
+#define CLUTTER_PARAM_ANIMATABLE        (1 << G_PARAM_USER_SHIFT)
+
 /* automagic interning of a static string */
 #define I_(str)  (g_intern_static_string ((str)))
 
@@ -191,6 +193,9 @@ typedef struct
 gboolean _clutter_threads_dispatch      (gpointer data);
 void     _clutter_threads_dispatch_free (gpointer data);
 
+void                    _clutter_threads_acquire_lock                   (void);
+void                    _clutter_threads_release_lock                   (void);
+
 ClutterMainContext *    _clutter_context_get_default                    (void);
 void                    _clutter_context_lock                           (void);
 void                    _clutter_context_unlock                         (void);
@@ -232,7 +237,7 @@ gboolean _clutter_boolean_handled_accumulator (GSignalInvocationHint *ihint,
                                                const GValue          *handler_return,
                                                gpointer               dummy);
 
-void _clutter_run_repaint_functions (void);
+void _clutter_run_repaint_functions (ClutterRepaintFlags flags);
 
 void _clutter_constraint_update_allocation (ClutterConstraint *constraint,
                                             ClutterActor      *actor,
@@ -265,6 +270,13 @@ typedef enum _ClutterCullResult
   CLUTTER_CULL_RESULT_PARTIAL
 } ClutterCullResult;
 
+gboolean        _clutter_has_progress_function  (GType gtype);
+gboolean        _clutter_run_progress_function  (GType gtype,
+                                                 const GValue *initial,
+                                                 const GValue *final,
+                                                 gdouble progress,
+                                                 GValue *retval);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_PRIVATE_H__ */
