@@ -29,7 +29,7 @@
  *   #ClutterTimeline
  *
  * #ClutterAnimation is an object providing simple, implicit animations
- * for #GObjects.
+ * for #GObject<!-- -->s.
  *
  * #ClutterAnimation instances will bind one or more #GObject properties
  * belonging to a #GObject to a #ClutterInterval, and will then use a
@@ -57,44 +57,91 @@
  * #ClutterAnimatable interface it is possible for that instance to
  * control the way the initial and final states are interpolated.
  *
- * #ClutterAnimations are distinguished from #ClutterBehaviours
+ * #ClutterAnimation<!-- -->s are distinguished from #ClutterBehaviour<!-- -->s
  * because the former can only control #GObject properties of a single
  * #GObject instance, while the latter can control multiple properties
  * using accessor functions inside the #ClutterBehaviour
- * `alpha_notify` virtual function, and can control multiple #ClutterActors
- * as well.
+ * <function>alpha_notify</function> virtual function, and can control
+ * multiple #ClutterActor<!-- -->s as well.
  *
  * For convenience, it is possible to use the clutter_actor_animate()
  * function call which will take care of setting up and tearing down
  * a #ClutterAnimation instance and animate an actor between its current
  * state and the specified final state.
  *
+ * <refsect2 id="clutter-AnimationMode-Script">
+ *   <title>Defining ClutterAnimationMode inside ClutterScript</title>
+ *   <para>When defining a #ClutterAnimation inside a ClutterScript
+ *   file or string the #ClutterAnimation:mode can be defined either
+ *   using the #ClutterAnimationMode enumeration values through their
+ *   "nick" (the short string used inside #GEnumValue), their numeric
+ *   id, or using the following strings:</para>
+ *   <variablelist>
+ *     <varlistentry>
+ *       <term>easeInQuad, easeOutQuad, easeInOutQuad</term>
+ *       <listitem><para>Corresponding to the quadratic easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInCubic, easeOutCubic, easeInOutCubic</term>
+ *       <listitem><para>Corresponding to the cubic easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInQuart, easeOutQuart, easeInOutQuart</term>
+ *       <listitem><para>Corresponding to the quartic easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInQuint, easeOutQuint, easeInOutQuint</term>
+ *       <listitem><para>Corresponding to the quintic easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInSine, easeOutSine, easeInOutSine</term>
+ *       <listitem><para>Corresponding to the sine easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInExpo, easeOutExpo, easeInOutExpo</term>
+ *       <listitem><para>Corresponding to the exponential easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInCirc, easeOutCirc, easeInOutCirc</term>
+ *       <listitem><para>Corresponding to the circular easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInElastic, easeOutElastic, easeInOutElastic</term>
+ *       <listitem><para>Corresponding to the overshooting elastic
+ *       easing modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInBack, easeOutBack, easeInOutBack</term>
+ *       <listitem><para>Corresponding to the overshooting cubic
+ *       easing modes</para></listitem>
+ *     </varlistentry>
+ *     <varlistentry>
+ *       <term>easeInBounce, easeOutBounce, easeInOutBounce</term>
+ *       <listitem><para>Corresponding to the bouncing easing
+ *       modes</para></listitem>
+ *     </varlistentry>
+ *   </variablelist>
+ * </refsect2>
+ *
+ * <example id="example-clutter-animation">
+ *   <title>Tweening using clutter_actor_animate()</title>
+ *   <programlisting>
+ * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../tests/interactive/test-easing.c">
+ *   <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
+ * </xi:include>
+ *   </programlisting>
+ * </example>
+ *
  * #ClutterAnimation is available since Clutter 1.0.
  *
- * #ClutterAnimation has been deprecated in Clutter 1.12. You should use
- * the [implicit animation API][clutter-actor-animation] available inside
- * #ClutterActor instead. If you require to define explicit transitions for
- * one or more properties in order to reuse them, see #ClutterTransition
- * instead.
- *
- * ## Defining ClutterAnimationMode inside ClutterScript
- *
- * When defining a #ClutterAnimation inside a ClutterScript
- * file or string the #ClutterAnimation:mode can be defined either
- * using the #ClutterAnimationMode enumeration values through their
- * "nick" (the short string used inside #GEnumValue), their numeric
- * id, or using the following strings:
- *
- *  - easeInQuad, easeOutQuad, easeInOutQuad
- *  - easeInCubic, easeOutCubic, easeInOutCubic
- *  - easeInQuart, easeOutQuart, easeInOutQuart
- *  - easeInQuint, easeOutQuint, easeInOutQuint
- *  - easeInSine, easeOutSine, easeInOutSine
- *  - easeInExpo, easeOutExpo, easeInOutExpo
- *  - easeInCirc, easeOutCirc, easeInOutCirc
- *  - easeInElastic, easeOutElastic, easeInOutElastic
- *  - easeInBack, easeOutBack, easeInOutBack
- *  - easeInBounce, easeOutBounce, easeInOutBounce
+ * #ClutterAnimation has been deprecated in Clutter 1.12.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -143,6 +190,8 @@ enum
   LAST_SIGNAL
 };
 
+#define CLUTTER_ANIMATION_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_ANIMATION, ClutterAnimationPrivate))
+
 struct _ClutterAnimationPrivate
 {
   GObject *object;
@@ -169,7 +218,6 @@ static ClutterAlpha *           clutter_animation_get_alpha_internal    (Clutter
 static ClutterTimeline *        clutter_animation_get_timeline_internal (ClutterAnimation *animation);
 
 G_DEFINE_TYPE_WITH_CODE (ClutterAnimation, clutter_animation, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (ClutterAnimation)
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
                                                 clutter_scriptable_init));
 
@@ -309,12 +357,6 @@ clutter_animation_dispose (GObject *gobject)
   priv->timeline_completed_id = 0;
   priv->timeline_frame_id = 0;
 
-  if (priv->timeline != NULL)
-    {
-      g_object_unref (priv->timeline);
-      priv->timeline = NULL;
-    }
-
   if (priv->alpha != NULL)
     {
       g_object_unref (priv->alpha);
@@ -447,6 +489,8 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
   quark_object_animation =
     g_quark_from_static_string ("clutter-actor-animation");
 
+  g_type_class_add_private (klass, sizeof (ClutterAnimationPrivate));
+
   klass->completed = clutter_animation_real_completed;
 
   gobject_class->set_property = clutter_animation_set_property;
@@ -599,7 +643,7 @@ clutter_animation_class_init (ClutterAnimationClass *klass)
 static void
 clutter_animation_init (ClutterAnimation *self)
 {
-  self->priv = clutter_animation_get_instance_private (self);
+  self->priv = CLUTTER_ANIMATION_GET_PRIVATE (self);
 
   self->priv->properties =
     g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -2088,10 +2132,7 @@ animation_create_for_actor (ClutterActor *actor)
  *
  * Since: 1.0
  *
- * Deprecated: 1.10: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.10: Use clutter_actor_animate_with_timeline() instead
  */
 ClutterAnimation *
 clutter_actor_animate_with_alpha (ClutterActor *actor,
@@ -2150,10 +2191,7 @@ clutter_actor_animate_with_alpha (ClutterActor *actor,
  *    g_object_unref()
  *
  * Since: 1.0
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 ClutterAnimation *
 clutter_actor_animate_with_timeline (ClutterActor    *actor,
@@ -2197,7 +2235,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *
  * For example, this:
  *
- * |[<!-- language="C" -->
+ * |[
  *   clutter_actor_animate (rectangle, CLUTTER_LINEAR, 250,
  *                          "width", 100.0,
  *                          "height", 100.0,
@@ -2215,10 +2253,10 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * the animation but not updated during the animation, it should be prefixed
  * by the "fixed::" string, for instance:
  *
- * |[<!-- language="C" -->
+ * |[
  *   clutter_actor_animate (actor, CLUTTER_EASE_IN_SINE, 100,
  *                          "rotation-angle-z", 360.0,
- *                          "fixed::rotation-center-z", &center,
+ *                          "fixed::rotation-center-z", &amp;center,
  *                          NULL);
  * ]|
  *
@@ -2236,7 +2274,8 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * are used as callback function and data for a signal handler installed on
  * the #ClutterAnimation object for the specified signal name, for instance:
  *
- * |[<!-- language="C" -->
+ * |[
+ *
  *   static void
  *   on_animation_completed (ClutterAnimation *animation,
  *                           ClutterActor     *actor)
@@ -2252,7 +2291,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *
  * or, to automatically destroy an actor at the end of the animation:
  *
- * |[<!-- language="C" -->
+ * |[
  *   clutter_actor_animate (actor, CLUTTER_EASE_IN_CUBIC, 100,
  *                          "opacity", 0,
  *                          "signal-swapped-after::completed",
@@ -2277,7 +2316,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * will cause the current animation to change with the new final values,
  * the new easing mode and the new duration - that is, this code:
  *
- * |[<!-- language="C" -->
+ * |[
  *   clutter_actor_animate (actor, CLUTTER_LINEAR, 250,
  *                          "width", 100.0,
  *                          "height", 100.0,
@@ -2291,7 +2330,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *
  * is the equivalent of:
  *
- * |[<!-- language="C" -->
+ * |[
  *   clutter_actor_animate (actor, CLUTTER_EASE_IN_CUBIC, 500,
  *                          "x", 100.0,
  *                          "y", 100.0,
@@ -2300,9 +2339,9 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *                          NULL);
  * ]|
  *
- * Unless the animation is looping, the #ClutterAnimation created by
+ * <note>Unless the animation is looping, the #ClutterAnimation created by
  * clutter_actor_animate() will become invalid as soon as it is
- * complete.
+ * complete.</note>
  *
  * Since the created #ClutterAnimation instance attached to @actor
  * is guaranteed to be valid throughout the #ClutterAnimation::completed
@@ -2311,7 +2350,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * #ClutterAnimation::completed signal handler unless you use
  * g_signal_connect_after() to connect the callback function, for instance:
  *
- * |[<!-- language="C" -->
+ * |[
  *   static void
  *   on_animation_completed (ClutterAnimation *animation,
  *                           ClutterActor     *actor)
@@ -2338,10 +2377,7 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *   g_object_unref()
  *
  * Since: 1.0
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 ClutterAnimation *
 clutter_actor_animate (ClutterActor *actor,
@@ -2389,18 +2425,15 @@ clutter_actor_animate (ClutterActor *actor,
  * This is the vector-based variant of clutter_actor_animate(), useful
  * for language bindings.
  *
- * Unlike clutter_actor_animate(), this function will not
- * allow you to specify "signal::" names and callbacks.
+ * <warning>Unlike clutter_actor_animate(), this function will not
+ * allow you to specify "signal::" names and callbacks.</warning>
  *
  * Return value: (transfer none): a #ClutterAnimation object. The object is
  *   owned by the #ClutterActor and should not be unreferenced with
  *   g_object_unref()
  *
  * Since: 1.0
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 ClutterAnimation *
 clutter_actor_animatev (ClutterActor        *actor,
@@ -2450,18 +2483,15 @@ clutter_actor_animatev (ClutterActor        *actor,
  * This is the vector-based variant of clutter_actor_animate_with_timeline(),
  * useful for language bindings.
  *
- * Unlike clutter_actor_animate_with_timeline(), this function
- * will not allow you to specify "signal::" names and callbacks.
+ * <warning>Unlike clutter_actor_animate_with_timeline(), this function
+ * will not allow you to specify "signal::" names and callbacks.</warning>
  *
  * Return value: (transfer none): a #ClutterAnimation object. The object is
  *    owned by the #ClutterActor and should not be unreferenced with
  *    g_object_unref()
  *
  * Since: 1.0
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 ClutterAnimation *
 clutter_actor_animate_with_timelinev (ClutterActor        *actor,
@@ -2509,18 +2539,15 @@ clutter_actor_animate_with_timelinev (ClutterActor        *actor,
  * This is the vector-based variant of clutter_actor_animate_with_alpha(),
  * useful for language bindings.
  *
- * Unlike clutter_actor_animate_with_alpha(), this function will
- * not allow you to specify "signal::" names and callbacks.
+ * <warning>Unlike clutter_actor_animate_with_alpha(), this function will
+ * not allow you to specify "signal::" names and callbacks.</warning>
  *
  * Return value: (transfer none): a #ClutterAnimation object. The object is owned by the
  *   #ClutterActor and should not be unreferenced with g_object_unref()
  *
  * Since: 1.0
  *
- * Deprecated: 1.10: Use the implicit transition for animatable properties
- *   in #ClutterActor instead. See clutter_actor_save_easing_state(),
- *   clutter_actor_set_easing_mode(), clutter_actor_set_easing_duration(),
- *   clutter_actor_set_easing_delay(), and clutter_actor_restore_easing_state().
+ * Deprecated: 1.10: Use clutter_actor_animate_with_timelinev() instead
  */
 ClutterAnimation *
 clutter_actor_animate_with_alphav (ClutterActor        *actor,
@@ -2563,9 +2590,7 @@ clutter_actor_animate_with_alphav (ClutterActor        *actor,
  * Return value: (transfer none): a #ClutterAnimation, or %NULL
  *
  * Since: 1.0
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead, and clutter_actor_get_transition() to retrieve
- *   the transition.
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 ClutterAnimation *
 clutter_actor_get_animation (ClutterActor *actor)
@@ -2588,9 +2613,7 @@ clutter_actor_get_animation (ClutterActor *actor)
  * The #ClutterAnimation::completed signal will not be emitted.
  *
  * Since: 1.4
- * Deprecated: 1.12: Use the implicit transition for animatable properties
- *   in #ClutterActor instead, and clutter_actor_remove_transition() to
- *   remove the transition.
+ * Deprecated: 1.12: Use #ClutterPropertyTransition instead
  */
 void
 clutter_actor_detach_animation (ClutterActor *actor)
